@@ -4,6 +4,7 @@ use warnings;
 use utf8;
 use File::pushd;
 use File::Spec;
+use File::Basename;
 
 use Minilla::Git;
 
@@ -14,6 +15,11 @@ has exclude_match => (
     default => sub { +[ ] },
 );
 
+has include_dotfiles => (
+    is => 'ro',
+    default => sub { undef },
+);
+
 no Moo;
 
 sub gather_files {
@@ -28,6 +34,11 @@ sub gather_files {
             @files = grep { _normalize($_) !~ $pattern } @files;
         }
     }
+
+    unless ($self->include_dotfiles) {
+        @files = grep { basename($_) !~ qr/^\./ } @files;
+    }
+
     return @files;
 }
 
